@@ -32,6 +32,7 @@
 #include <ktexteditor/markinterface.h>
 #include <ktexteditor/movinginterface.h>
 #include <ktexteditor/movingrange.h>
+#include <ktexteditor/configinterface.h>
 
 #include <kaction.h>
 #include <kactioncollection.h>
@@ -45,6 +46,7 @@
 #include <QClipboard>
 #include <QMenu>
 #include <QTextDocument>
+#include <QScrollBar>
 
 static QAction *menuEntry(QMenu *menu,
                           const QString &before, const QString &after, const QString &desc,
@@ -174,7 +176,6 @@ m_curResults(0)
     m_ui.displayOptions->setIcon(KIcon("arrow-down-double"));
     m_ui.searchButton->setIcon(KIcon("edit-find"));
     m_ui.stopButton->setIcon(KIcon("process-stop"));
-    m_ui.optionsButton->setIcon(KIcon("configure"));
     m_ui.searchPlaceCombo->setItemIcon(0, KIcon("text-plain"));
     m_ui.searchPlaceCombo->setItemIcon(1, KIcon("folder"));
     m_ui.folderUpButton->setIcon(KIcon("go-up"));
@@ -184,10 +185,11 @@ m_curResults(0)
     m_ui.filterCombo->setToolTip(i18n("Comma separated list of file types to search in. example: \"*.cpp,*.h\"\n"
     "NOTE: Put a minus sign ('-') in front of the list to make it into an exclude list. example: \"-*.o,*.obj\""));
 
-    int padWidth = m_ui.folderLabel->width();
-    padWidth = qMax(padWidth, m_ui.filterLabel->width());
-    m_ui.gridLayout->setColumnMinimumWidth(0, padWidth);
-    m_ui.gridLayout->setAlignment(m_ui.newTabButton, Qt::AlignHCenter);
+    int padWidth = m_ui.folderLabel->sizeHint().width();
+    padWidth = qMax(padWidth, m_ui.filterLabel->sizeHint().width());
+    m_ui.topLayout->setColumnMinimumWidth(0, padWidth);
+    m_ui.topLayout->setAlignment(m_ui.newTabButton, Qt::AlignHCenter);
+    m_ui.optionsLayout->setColumnMinimumWidth(0, padWidth);
 
     // the order here is important to get the tabBar hidden for only one tab
     addTab();
@@ -202,14 +204,6 @@ m_curResults(0)
     cmbUrl->setCompletionObject(cmpl);
     cmbUrl->setAutoDeleteCompletionObject(true);
 
-    m_matchCase = new KAction(i18n("Match case"), this);
-    m_matchCase->setCheckable(true);
-    m_ui.optionsButton->addAction(m_matchCase);
-
-    m_useRegExp = new KAction(i18n("Regular Expression"), this);
-    m_useRegExp->setCheckable(true);
-    m_ui.optionsButton->addAction(m_useRegExp);
-
     connect(m_ui.newTabButton,     SIGNAL(clicked()), this, SLOT(addTab()));
     connect(m_ui.resultTabWidget,  SIGNAL(closeRequest(QWidget*)), this, SLOT(closeTab(QWidget*)));
     connect(m_ui.resultTabWidget,  SIGNAL(currentChanged(int)), this, SLOT(resultTabChanged(int)));
@@ -254,6 +248,9 @@ m_curResults(0)
     connect(m_ui.searchCombo, SIGNAL(customContextMenuRequested(QPoint)), this,
             SLOT(searchContextMenu(QPoint)));
 
+    connect(mainWindow(), SIGNAL(unhandledShortcutOverride(QEvent*)),
+            this, SLOT(handleEsc(QEvent*)));
+
     m_replacer.setDocumentManager(m_kateApp->documentManager());
 
     searchPlaceChanged();
@@ -319,6 +316,22 @@ void KatePluginSearchView::openSearchView()
     }
 }
 
+void KatePluginSearchView::handleEsc(QEvent *e)
+{
+    if (!mainWindow()) return;
+
+    QKeyEvent *k = static_cast<QKeyEvent *>(e);
+    if (k->key() == Qt::Key_Escape && k->modifiers() == Qt::NoModifier) {
+
+        if (m_toolView->isVisible()) {
+            mainWindow()->hideToolView(m_toolView);
+        }
+        else {
+            clearMarks();
+        }
+    }
+}
+
 void KatePluginSearchView::setSearchString(const QString &pattern)
 {
     m_ui.searchCombo->lineEdit()->setText(pattern);
@@ -343,13 +356,12 @@ void KatePluginSearchView::startSearch()
     m_ui.searchCombo->setDisabled(true);
     m_ui.searchButton->setDisabled(true);
     m_ui.locationAndStop->setCurrentIndex(1);
-    m_ui.optionsButton->setDisabled(true);
     m_ui.displayOptions->setChecked (false);
     m_ui.displayOptions->setDisabled(true);
 
     QRegExp reg(m_ui.searchCombo->currentText(),
-                m_matchCase->isChecked() ? Qt::CaseSensitive : Qt::CaseInsensitive,
-                m_useRegExp->isChecked() ? QRegExp::RegExp : QRegExp::FixedString);
+                m_ui.matchCase->isChecked() ? Qt::CaseSensitive : Qt::CaseInsensitive,
+                m_ui.useRegExp->isChecked() ? QRegExp::RegExp : QRegExp::FixedString);
     m_curResults->regExp = reg;
 
     clearMarks();
@@ -371,6 +383,7 @@ void KatePluginSearchView::startSearch()
                                    m_ui.recursiveCheckBox->isChecked(),
                                    m_ui.hiddenCheckBox->isChecked(),
                                    m_ui.symLinkCheckBox->isChecked(),
+                                   m_ui.binaryCheckBox->isChecked(),
                                    m_ui.filterCombo->currentText(),
                                    reg);
     }
@@ -438,12 +451,17 @@ void KatePluginSearchView::addMatchMark(KTextEditor::Document* doc, int line, in
     if (!doc) return;
 
     KTextEditor::MovingInterface* miface = qobject_cast<KTextEditor::MovingInterface*>(doc);
+    KTextEditor::ConfigInterface* ciface = qobject_cast<KTextEditor::ConfigInterface*>(doc->activeView());
     KTextEditor::Attribute::Ptr attr(new KTextEditor::Attribute());
     if (sender() == &m_replacer) {
-        attr->setBackground(Qt::green); // TODO make this part of the color scheme
+        QColor replaceColor(Qt::green);
+        if (ciface) replaceColor = ciface->configValue("replace-highlight-color").value<QColor>();
+        attr->setBackground(replaceColor);
     }
     else {
-        attr->setBackground(Qt::yellow); // TODO make this part of the color scheme
+        QColor searchColor(Qt::yellow);
+        if (ciface) searchColor = ciface->configValue("search-highlight-color").value<QColor>();
+        attr->setBackground(searchColor);
     }
     KTextEditor::Range range(line, column, line, column+matchLen);
     KTextEditor::MovingRange* mr = miface->newMovingRange(range);
@@ -554,7 +572,6 @@ void KatePluginSearchView::searchDone()
     m_ui.searchCombo->setDisabled(false);
     m_ui.searchButton->setDisabled(false);
     m_ui.locationAndStop->setCurrentIndex(0);
-    m_ui.optionsButton->setDisabled(false);
     m_ui.displayOptions->setDisabled(false);
 
     if (!m_curResults) {
@@ -566,7 +583,11 @@ void KatePluginSearchView::searchDone()
     }
     m_curResults->tree->expandAll();
     m_curResults->tree->resizeColumnToContents(0);
-    m_curResults->tree->collapseAll();
+    if (m_curResults->tree->verticalScrollBar()->maximum() >
+        3*m_curResults->tree->verticalScrollBar()->pageStep())
+    {
+        m_curResults->tree->collapseAll();
+    }
     m_curResults->buttonContainer->setEnabled(true);
 
     connect(m_curResults->tree, SIGNAL(itemChanged(QTreeWidgetItem*,int)), m_curResults, SLOT(checkCheckedState()));
@@ -704,13 +725,14 @@ void KatePluginSearchView::readSessionConfig(KConfigBase* config, const QString&
     KConfigGroup cg(config, groupPrefix + ":search-plugin");
     m_ui.searchCombo->clearHistory();
     m_ui.searchCombo->setHistoryItems(cg.readEntry("Search", QStringList()), true);
-    m_matchCase->setChecked(cg.readEntry("MatchCase", false));
-    m_useRegExp->setChecked(cg.readEntry("UseRegExp", false));
+    m_ui.matchCase->setChecked(cg.readEntry("MatchCase", false));
+    m_ui.useRegExp->setChecked(cg.readEntry("UseRegExp", false));
 
     m_ui.searchPlaceCombo->setCurrentIndex(cg.readEntry("Place", 0));
     m_ui.recursiveCheckBox->setChecked(cg.readEntry("Recursive", true));
     m_ui.hiddenCheckBox->setChecked(cg.readEntry("HiddenFiles", false));
     m_ui.symLinkCheckBox->setChecked(cg.readEntry("FollowSymLink", false));
+    m_ui.binaryCheckBox->setChecked(cg.readEntry("BinaryFiles", false));
     m_ui.folderRequester->comboBox()->clear();
     m_ui.folderRequester->comboBox()->addItems(cg.readEntry("SearchFolders", QStringList()));
     m_ui.folderRequester->setText(cg.readEntry("SearchFolder", QString()));
@@ -723,13 +745,14 @@ void KatePluginSearchView::writeSessionConfig(KConfigBase* config, const QString
 {
     KConfigGroup cg(config, groupPrefix + ":search-plugin");
     cg.writeEntry("Search", m_ui.searchCombo->historyItems());
-    cg.writeEntry("MatchCase", m_matchCase->isChecked());
-    cg.writeEntry("UseRegExp", m_useRegExp->isChecked());
+    cg.writeEntry("MatchCase", m_ui.matchCase->isChecked());
+    cg.writeEntry("UseRegExp", m_ui.useRegExp->isChecked());
 
     cg.writeEntry("Place", m_ui.searchPlaceCombo->currentIndex());
     cg.writeEntry("Recursive", m_ui.recursiveCheckBox->isChecked());
     cg.writeEntry("HiddenFiles", m_ui.hiddenCheckBox->isChecked());
     cg.writeEntry("FollowSymLink", m_ui.symLinkCheckBox->isChecked());
+    cg.writeEntry("BinaryFiles", m_ui.binaryCheckBox->isChecked());
     QStringList folders;
     for (int i=0; i<qMin(m_ui.folderRequester->comboBox()->count(), 10); i++) {
         folders << m_ui.folderRequester->comboBox()->itemText(i);
@@ -808,8 +831,8 @@ void KatePluginSearchView::resultTabChanged(int index)
     }
 
     m_ui.searchCombo->lineEdit()->setText(m_ui.resultTabWidget->tabText(index));
-    m_matchCase->setChecked(res->regExp.caseSensitivity() == Qt::CaseSensitive);
-    m_useRegExp->setChecked(res->regExp.patternSyntax() != QRegExp::FixedString);
+    m_ui.matchCase->setChecked(res->regExp.caseSensitivity() == Qt::CaseSensitive);
+    m_ui.useRegExp->setChecked(res->regExp.patternSyntax() != QRegExp::FixedString);
 }
 
 
@@ -836,7 +859,6 @@ bool KatePluginSearchView::eventFilter(QObject *obj, QEvent *event)
         }
         if ((obj == m_toolView) && (ke->key() == Qt::Key_Escape)) {
             mainWindow()->hideToolView(m_toolView);
-            clearMarks();
             event->accept();
             return true;
         }
@@ -851,7 +873,7 @@ void KatePluginSearchView::searchContextMenu(const QPoint& pos)
     QMenu* const contextMenu = m_ui.searchCombo->lineEdit()->createStandardContextMenu();
     if (!contextMenu) return;
 
-    if (m_useRegExp->isChecked()) {
+    if (m_ui.useRegExp->isChecked()) {
         QMenu* menu = contextMenu->addMenu(i18n("Add..."));
         if (!menu) return;
 
@@ -917,11 +939,9 @@ void KatePluginSearchView::replaceChecked()
 
 void KatePluginSearchView::replaceDone()
 {
-    if (m_curResults) {
-        m_curResults->buttonStack->setCurrentIndex(0);
-        m_curResults->replaceCombo->setDisabled(false);
-        m_curResults = 0;
-    }
+    m_curResults->buttonStack->setCurrentIndex(0);
+    m_curResults->replaceCombo->setDisabled(false);
+    m_curResults = 0;
 }
 
 KateSearchCommand::KateSearchCommand(QObject *parent)
