@@ -28,6 +28,7 @@
 #include <math.h>
 
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kglobalsettings.h>
 #include <kcolorscheme.h>
 #include <kcolorutils.h>
@@ -178,6 +179,7 @@ KateDocumentConfig::KateDocumentConfig ()
    m_replaceTabsDynSet (false),
    m_removeTrailingDynSet (false),
    m_removeSpacesSet (false),
+   m_newLineAtEofSet (false),
    m_overwiteModeSet (false),
    m_tabIndentsSet (false),
    m_encodingSet (true),
@@ -264,6 +266,7 @@ KateDocumentConfig::KateDocumentConfig (KateDocument *doc)
    m_replaceTabsDynSet (false),
    m_removeTrailingDynSet (false),
    m_removeSpacesSet (false),
+   m_newLineAtEofSet (false),
    m_overwiteModeSet (false),
    m_tabIndentsSet (false),
    m_encodingSet (false),
@@ -314,6 +317,7 @@ void KateDocumentConfig::readConfig (const KConfigGroup &config)
   setReplaceTabsDyn (config.readEntry("ReplaceTabsDyn", false));
   setRemoveTrailingDyn (config.readEntry("RemoveTrailingDyn", false));
   setRemoveSpaces (config.readEntry("Remove Spaces", false));
+  setNewLineAtEof (config.readEntry("Newline At EOF", false));
   setOvr (config.readEntry("Overwrite Mode", false));
 
   setEncoding (config.readEntry("Encoding", ""));
@@ -368,6 +372,7 @@ void KateDocumentConfig::writeConfig (KConfigGroup &config)
   config.writeEntry("ReplaceTabsDyn", replaceTabsDyn());
   config.writeEntry("RemoveTrailingDyn", removeTrailingDyn());
   config.writeEntry("Remove Spaces", removeSpaces());
+  config.writeEntry("Newline At EOF", newLineAtEof());
   config.writeEntry("Overwrite Mode", ovr());
 
   config.writeEntry("Encoding", encoding());
@@ -743,6 +748,24 @@ bool KateDocumentConfig::removeSpaces() const
   return s_global->removeSpaces();
 }
 
+void KateDocumentConfig::setNewLineAtEof (bool on)
+{
+  configStart ();
+
+  m_newLineAtEofSet = true;
+  m_newLineAtEof = on;
+
+  configEnd ();
+}
+
+bool KateDocumentConfig::newLineAtEof () const
+{
+  if (m_newLineAtEofSet || isGlobal())
+    return m_newLineAtEof;
+
+  return s_global->newLineAtEof();
+}
+
 void KateDocumentConfig::setOvr(bool on)
 {
   configStart ();
@@ -1146,7 +1169,7 @@ void KateViewConfig::readConfig ( const KConfigGroup &config)
 
   setFoldingBar (config.readEntry( "Folding Bar", true));
 
-  setLineModification (config.readEntry( "Line Modification", true));
+  setLineModification (config.readEntry( "Line Modification", false));
 
   setBookmarkSort (config.readEntry( "Bookmark Menu Sorting", 0 ));
 
@@ -1708,10 +1731,16 @@ KateRendererConfig::KateRendererConfig ()
    m_highlightedBracketColorSet (true),
    m_wordWrapMarkerColorSet (true),
    m_tabMarkerColorSet(true),
-   m_iconBarColorSet (true),
+   m_indentationLineColorSet(true),
+   m_iconBarColorSet(true),
+   m_foldingColorSet(true),
    m_lineNumberColorSet (true),
    m_spellingMistakeLineColorSet (true),
    m_templateColorsSet(true),
+   m_modifiedLineColorSet(true),
+   m_savedLineColorSet(true),
+   m_searchHighlightColorSet(true),
+   m_replaceHighlightColorSet(true),
    m_lineMarkerColorSet (m_lineMarkerColor.size()),
    m_renderer (0)
 {
@@ -1738,11 +1767,17 @@ KateRendererConfig::KateRendererConfig (KateRenderer *renderer)
    m_highlightedLineColorSet (false),
    m_highlightedBracketColorSet (false),
    m_wordWrapMarkerColorSet (false),
-   m_tabMarkerColorSet(false),
+   m_tabMarkerColorSet (false),
+   m_indentationLineColorSet (false),
    m_iconBarColorSet (false),
+   m_foldingColorSet (false),
    m_lineNumberColorSet (false),
    m_spellingMistakeLineColorSet (false),
    m_templateColorsSet(false),
+   m_modifiedLineColorSet(false),
+   m_savedLineColorSet(false),
+   m_searchHighlightColorSet(false),
+   m_replaceHighlightColorSet(false),
    m_lineMarkerColorSet (m_lineMarkerColor.size()),
    m_renderer (renderer)
 {
@@ -1814,9 +1849,11 @@ void KateRendererConfig::setSchema (const QString &schema)
 
 void KateRendererConfig::reloadSchema()
 {
-  if ( isGlobal() )
+  if ( isGlobal() ) {
+    setSchemaInternal( m_schema );
     foreach (KateView* view, KateGlobal::self()->views() )
       view->renderer()->config()->reloadSchema();
+  }
 
   else if ( m_renderer && m_schemaSet )
     setSchemaInternal( m_schema );
@@ -1833,7 +1870,6 @@ void KateRendererConfig::setSchemaInternal( const QString &schema )
   KColorScheme schemeView(QPalette::Active, KColorScheme::View);
   KColorScheme schemeWindow(QPalette::Active, KColorScheme::Window);
   KColorScheme schemeSelection(QPalette::Active, KColorScheme::Selection);
-  KColorScheme schemeTooltip(QPalette::Active, KColorScheme::Tooltip);
   QColor tmp0( schemeView.background().color() );
   QColor tmp1( schemeSelection.background().color() );
   QColor tmp2( schemeView.background(KColorScheme::AlternateBackground).color() );
@@ -1845,6 +1881,10 @@ void KateRendererConfig::setSchemaInternal( const QString &schema )
   QColor tmp6( schemeWindow.background().color() );
   QColor tmp7( schemeWindow.foreground().color() );
   QColor tmp8( schemeView.foreground(KColorScheme::NegativeText).color() );
+  QColor tmp9( schemeView.background(KColorScheme::NegativeBackground).color() );
+  QColor tmp10( schemeView.background(KColorScheme::PositiveBackground).color() );
+  QColor tmp11( schemeView.background(KColorScheme::NeutralBackground).color() );
+  QColor tmp12( KColorScheme(QPalette::Inactive, KColorScheme::Selection).background().color() );
 
   m_backgroundColor = config.readEntry("Color Background", tmp0);
   m_backgroundColorSet = true;
@@ -1858,13 +1898,27 @@ void KateRendererConfig::setSchemaInternal( const QString &schema )
   m_wordWrapMarkerColorSet = true;
   m_tabMarkerColor = config.readEntry("Color Tab Marker", tmp5);
   m_tabMarkerColorSet = true;
+  m_indentationLineColor = config.readEntry("Color Indentation Line", tmp5);
+  m_indentationLineColorSet = true;
   m_iconBarColor  = config.readEntry("Color Icon Bar", tmp6);
   m_iconBarColorSet = true;
+  m_foldingColor  = config.readEntry("Color Code Folding", tmp12);
+  m_foldingColorSet = true;
   m_lineNumberColor = config.readEntry("Color Line Number", tmp7);
   m_lineNumberColorSet = true;
   m_spellingMistakeLineColor = config.readEntry("Color Spelling Mistake Line", tmp8);
   m_spellingMistakeLineColorSet = true;
 
+  m_modifiedLineColor = config.readEntry("Color Modified Lines", tmp9);
+  m_modifiedLineColorSet = true;
+  m_savedLineColor = config.readEntry("Color Saved Lines", tmp10);
+  m_savedLineColorSet = true;
+  m_searchHighlightColor = config.readEntry("Color Search Highlight", tmp11);
+  m_searchHighlightColorSet = true;
+  m_replaceHighlightColor = config.readEntry("Color Replace Highlight", tmp10);
+  m_replaceHighlightColorSet = true;
+
+
     // same std colors like in KateDocument::markColor
   QColor mark[7];
   mark[0] = Qt::blue;
@@ -1888,17 +1942,17 @@ void KateRendererConfig::setSchemaInternal( const QString &schema )
   m_fontMetrics = QFontMetrics(m_font);
   m_fontSet = true;
 
-  m_templateBackgroundColor=config.readEntry(QString("Color Template Background"),
-                                             schemeTooltip.background(KColorScheme::NormalBackground).color());
+  QColor c = schemeWindow.background().color();
+  m_templateBackgroundColor = config.readEntry(QString("Color Template Background"), c);
 
-  m_templateEditablePlaceholderColor = config.readEntry(QString("Color Template Editable Placeholder"),
-                                                        schemeTooltip.background(KColorScheme::NeutralBackground).color());
+  c = schemeView.background(KColorScheme::PositiveBackground).color();
+  m_templateFocusedEditablePlaceholderColor = config.readEntry(QString("Color Template Focused Editable Placeholder"), c);
 
-  m_templateFocusedEditablePlaceholderColor=config.readEntry(QString("Color Template Focused Editable Placeholder"),
-                                                             schemeTooltip.background(KColorScheme::PositiveBackground).color());
+  c = schemeWindow.background(KColorScheme::PositiveBackground).color();
+  m_templateEditablePlaceholderColor = config.readEntry(QString("Color Template Editable Placeholder"), c);
 
-  m_templateNotEditablePlaceholderColor=config.readEntry(QString("Color Template Not Editable Placeholder"),
-                                                         schemeTooltip.background(KColorScheme::NegativeBackground).color());
+  c = schemeView.background(KColorScheme::NegativeBackground).color();
+  m_templateNotEditablePlaceholderColor = config.readEntry(QString("Color Template Not Editable Placeholder"), c);
 
   m_templateColorsSet=true;
 }
@@ -2086,6 +2140,24 @@ void KateRendererConfig::setTabMarkerColor (const QColor &col)
   configEnd ();
 }
 
+const QColor& KateRendererConfig::indentationLineColor() const
+{
+  if (m_indentationLineColorSet || isGlobal())
+    return m_indentationLineColor;
+
+  return s_global->indentationLineColor();
+}
+
+void KateRendererConfig::setIndentationLineColor (const QColor &col)
+{
+  configStart ();
+
+  m_indentationLineColorSet = true;
+  m_indentationLineColor = col;
+
+  configEnd ();
+}
+
 const QColor& KateRendererConfig::iconBarColor() const
 {
   if (m_iconBarColorSet || isGlobal())
@@ -2104,33 +2176,56 @@ void KateRendererConfig::setIconBarColor (const QColor &col)
   configEnd ();
 }
 
+const QColor& KateRendererConfig::foldingColor() const
+{
+  if (m_foldingColorSet || isGlobal())
+    return m_foldingColor;
 
-const QColor &KateRendererConfig::templateBackgroundColor() const {
+  return s_global->foldingColor();
+}
+
+void KateRendererConfig::setFoldingColor (const QColor &col)
+{
+  configStart ();
+
+  m_foldingColorSet = true;
+  m_foldingColor = col;
+
+  configEnd ();
+}
+
+const QColor &KateRendererConfig::templateBackgroundColor() const
+{
   if (m_templateColorsSet || isGlobal())
     return m_templateBackgroundColor;
 
   return s_global->templateBackgroundColor();
 }
-const QColor &KateRendererConfig::templateEditablePlaceholderColor() const {
+
+const QColor &KateRendererConfig::templateEditablePlaceholderColor() const
+{
   if (m_templateColorsSet || isGlobal())
     return m_templateEditablePlaceholderColor;
 
   return s_global->templateEditablePlaceholderColor();
 }
-const QColor &KateRendererConfig::templateFocusedEditablePlaceholderColor() const {
+
+const QColor &KateRendererConfig::templateFocusedEditablePlaceholderColor() const
+{
   if (m_templateColorsSet || isGlobal())
     return m_templateFocusedEditablePlaceholderColor;
 
   return s_global->templateFocusedEditablePlaceholderColor();
 }
-const QColor &KateRendererConfig::templateNotEditablePlaceholderColor() const {
+
+const QColor &KateRendererConfig::templateNotEditablePlaceholderColor() const
+{
   if (m_templateColorsSet || isGlobal())
     return m_templateNotEditablePlaceholderColor;
 
   return s_global->templateNotEditablePlaceholderColor();
 }
 
-
 const QColor& KateRendererConfig::lineNumberColor() const
 {
   if (m_lineNumberColorSet || isGlobal())
@@ -2157,7 +2252,7 @@ const QColor& KateRendererConfig::spellingMistakeLineColor() const
   return s_global->spellingMistakeLineColor();
 }
 
-void KateRendererConfig::setSpellingMistakeKineColor (const QColor &col)
+void KateRendererConfig::setSpellingMistakeLineColor (const QColor &col)
 {
   configStart ();
 
@@ -2167,6 +2262,79 @@ void KateRendererConfig::setSpellingMistakeKineColor (const QColor &col)
   configEnd ();
 }
 
+const QColor& KateRendererConfig::modifiedLineColor() const
+{
+  if (m_modifiedLineColorSet || isGlobal())
+    return m_modifiedLineColor;
+
+  return s_global->modifiedLineColor();
+}
+
+void KateRendererConfig::setModifiedLineColor(const QColor &col)
+{
+  configStart ();
+
+  m_modifiedLineColorSet = true;
+  m_modifiedLineColor = col;
+
+  configEnd ();
+}
+
+const QColor& KateRendererConfig::savedLineColor() const
+{
+  if (m_savedLineColorSet || isGlobal())
+    return m_savedLineColor;
+
+  return s_global->savedLineColor();
+}
+
+void KateRendererConfig::setSavedLineColor(const QColor &col)
+{
+  configStart ();
+
+  m_savedLineColorSet = true;
+  m_savedLineColor = col;
+
+  configEnd ();
+}
+
+const QColor& KateRendererConfig::searchHighlightColor() const
+{
+  if (m_searchHighlightColorSet || isGlobal())
+    return m_searchHighlightColor;
+
+  return s_global->searchHighlightColor();
+}
+
+void KateRendererConfig::setSearchHighlightColor(const QColor &col)
+{
+  configStart ();
+
+  m_searchHighlightColorSet = true;
+  m_searchHighlightColor = col;
+
+  configEnd ();
+}
+
+const QColor& KateRendererConfig::replaceHighlightColor() const
+{
+  if (m_replaceHighlightColorSet || isGlobal())
+    return m_replaceHighlightColor;
+
+  return s_global->replaceHighlightColor();
+}
+
+void KateRendererConfig::setReplaceHighlightColor(const QColor &col)
+{
+  configStart ();
+
+  m_replaceHighlightColorSet = true;
+  m_replaceHighlightColor = col;
+
+  configEnd ();
+}
+
+
 bool KateRendererConfig::showIndentationLines () const
 {
   if (m_showIndentationLinesSet || isGlobal())
