@@ -100,6 +100,11 @@ bool KateViNormalMode::handleKeypress( const QKeyEvent *e )
     return false;
   }
 
+  if ( keyCode == Qt::Key_AltGr ) {
+    KateViKeyParser::getInstance()->setAltGrStatus( true );
+    return true;
+  }
+
   if ( keyCode == Qt::Key_Escape ) {
     reset();
     return true;
@@ -401,6 +406,8 @@ void KateViNormalMode::resetParser()
   m_linewiseCommand = true;
   m_deleteCommand = false;
 
+  m_commandShouldKeepSelection = false;
+
 }
 
 // reset the command parser
@@ -698,9 +705,6 @@ bool KateViNormalMode::commandDeleteToEOL()
   if ( c.line() < 0 ) {
     c.setLine( 0 );
   }
-  if ( c.line() > doc()->lastLine() ) {
-    c.setLine( doc()->lastLine() );
-  }
   if ( c.column() > doc()->lineLength( c.line() )-1 ) {
     c.setColumn( doc()->lineLength( c.line() )-1 );
   }
@@ -1269,7 +1273,7 @@ bool KateViNormalMode::commandSwitchToCmdLine()
       || m_viInputModeManager->getCurrentViMode() == VisualBlockMode ) {
       // if in visual mode, make command range == visual selection
       m_viInputModeManager->getViVisualMode()->saveRangeMarks();
-      m_view->cmdLineBar()->setText( "'<,'>" );
+      m_view->cmdLineBar()->setText( "'<,'>", false );
     }
     else if ( getCount() != 1 ) {
       // if a count is given, the range [current line] to [current line] +
@@ -1277,6 +1281,8 @@ bool KateViNormalMode::commandSwitchToCmdLine()
       m_view->cmdLineBar()->setText( ".,.+" +QString::number( getCount()-1 ), false);
     }
 
+    m_commandShouldKeepSelection = true;
+
     return true;
 }
 
